Skip to contents

Three UTF-8 character vectors of stopwords bundled with jiebaRS. They are provided for explicit use with the stop_word argument; none is enabled by default.

Usage

data(stopwords_cn)

data(stopwords_en)

data(stopwords_full)

Format

Three character vectors:

stopwords_cn

A compiled Chinese stopword list. The upstream list also contains some punctuation, numbers, and English entries.

stopwords_en

A commonly used English stopword list.

stopwords_full

A combined Chinese and English stopword list.

Examples

cutter <- worker(stop_word = stopwords_cn)
segment("\u8fd9\u662f\u4e00\u4e2a\u6d4b\u8bd5", cutter)
#> [1] "这是" "测试"