Generate IDF dict from a list of documents.
Arguments
- x
a list of character vectors. Each vector represents a document of already-segmented words.
- stop_word
Optional character vector of stop words supplied directly.
- stop_word_file
Optional file path containing one stop word per line.
- path
Optional output file path. When
NULL, a data frame is returned. Otherwise, the result is written to the file asword idf_valueper line (the format expected byworker(type = "keywords", idf = ...)) and the path is returned invisibly.